/**
 * API RESTful for OSSEC
 * Copyright (C) 2015-2016 Wazuh, Inc.All rights reserved.
 * Wazuh.com
 *
 * This program is a free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public
 * License (version 2) as published by the FSF - Free Software
 * Foundation.
 */


errors = require('../helpers/errors');
filter = require('../helpers/filters');
execute = require('../helpers/execute');
apicache  = require('apicache');
cache     = apicache.middleware;
wazuh_control = api_path + "/models/wazuh-api.py";

var router = require('express').Router();
var validator = require('../helpers/input_validation');


// Cache options
if (config.cache_enabled.toLowerCase() == "yes"){
    if (config.cache_debug.toLowerCase() == "yes")
        cache_debug = true;
    else
        cache_debug = false;
    cache_opt = { debug: cache_debug, defaultDuration: parseInt(config.cache_time)};
}
else
    cache_opt = { enabled: false };

apicache.options(cache_opt);

// Content-type
router.post("*", function(req, res, next) {
    var content_type = req.get('Content-Type');

    if (!content_type || !(content_type == 'application/json' || content_type == 'application/x-www-form-urlencoded')){
        logger.debug(req.connection.remoteAddress + " POST " + req.path);
        res_h.bad_request(req, res, "607");
    }
    else
        next();
});

// All requests
router.all("*", function(req, res, next) {
    var go_next = true;
    res_h.pretty = false;

    if (req.query){
        // Pretty
        if ("pretty" in req.query){
            res_h.pretty = true;
            delete req.query["pretty"];
        }
    }

    if (go_next)
        next();
});

// Controllers
router.use('/agents', require('./agents'));
router.use('/manager', require('./manager'));
router.use('/syscheck', require('./syscheck'));
router.use('/rootcheck', require('./rootcheck'));
router.use('/rules', require('./rules'));
router.use('/decoders', require('./decoders'));
router.use('/cache', require('./cache'));

// Index
router.get('/',function(req, res) {
    logger.debug(req.connection.remoteAddress + " GET /");
    json_res = {'error': 0, 'data': "Welcome to Wazuh HIDS API"};
    res_h.send(req, res, json_res);
});

// Version
router.get('/version',function(req, res) {
    logger.debug(req.connection.remoteAddress + " GET /version");

    // Temporary patch
    if( !req.get('wazuh-app-version') && req.get('user-agent') && req.get('user-agent').startsWith('Needle')){
        json_res = {'error': 0, 'data': "v2.0.0"};
    }
    else{
        json_res = {'error': 0, 'data': "v" + info_package.version};
    }

    res_h.send(req, res, json_res);
});

// ALWAYS Keep this as the last route
router.all('*',function(req, res) {
    logger.debug(req.connection.remoteAddress + " " + req.method + " " + req.path);
    json_res = { 'error': 603, 'message': errors.description(603)};
    res_h.send(req, res, json_res, 404);
});


// Router Errors
router.use(function(err, req, res, next){
    logger.log("Internal Error");
    if(err.stack)
        logger.log(err.stack);
    logger.log("Exiting...");

    setTimeout(function(){ process.exit(1); }, 500);
});



module.exports = router
